@@ -39,7 +39,7 @@ func TestNewElasticsearchCRWhenNodeSelectorIsDefined(t *testing.T) {
 	}
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeSelector: expSelector,
@@ -58,7 +58,7 @@ func TestNewElasticsearchCRWhenNodeSelectorIsDefined(t *testing.T) {
 func TestNewElasticsearchCRWhenResourcesAreDefined(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
@@ -91,7 +91,7 @@ func TestDifferenceFoundWhenResourcesAreChanged(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
@@ -103,7 +103,7 @@ func TestDifferenceFoundWhenResourcesAreChanged(t *testing.T) {
 
 	cluster = &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					Resources: newResourceRequirements("10Gi", "", "12Gi", "500m"),
@@ -122,7 +122,7 @@ func TestDifferenceFoundWhenResourcesAreChanged(t *testing.T) {
 func TestDifferenceFoundWhenNodeCountIsChanged(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 1,
@@ -134,7 +134,7 @@ func TestDifferenceFoundWhenNodeCountIsChanged(t *testing.T) {
 
 	cluster = &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 2,
@@ -153,7 +153,7 @@ func TestDifferenceFoundWhenNodeCountIsChanged(t *testing.T) {
 func TestDefaultRedundancyUsedWhenOmitted(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type:              "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{},
 			},
@@ -170,7 +170,7 @@ func TestDefaultRedundancyUsedWhenOmitted(t *testing.T) {
 func TestUseRedundancyWhenSpecified(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					RedundancyPolicy: elasticsearch.SingleRedundancy,
@@ -196,7 +196,7 @@ func TestNotSplitRolesWhenNodeCountIsEq3(t *testing.T) {
 func TestSplitRolesWhenNodeCountIsGt3(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 4,
@@ -256,7 +256,7 @@ func TestSplitRolesWhenNodeCountIsGt3(t *testing.T) {
 func createAndCheckSingleNodeWithNodeCount(t *testing.T, expectedNodeCount int32) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: expectedNodeCount,
@@ -291,7 +291,7 @@ func createAndCheckSingleNodeWithNodeCount(t *testing.T, expectedNodeCount int32
 func TestDifferenceFoundWhenNodeCountExceeds3(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 3,
@@ -303,7 +303,7 @@ func TestDifferenceFoundWhenNodeCountExceeds3(t *testing.T) {
 
 	cluster = &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 4,
@@ -322,7 +322,7 @@ func TestDifferenceFoundWhenNodeCountExceeds3(t *testing.T) {
 func TestDifferenceFoundWhenNodeCountExceeds4(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 4,
@@ -334,7 +334,7 @@ func TestDifferenceFoundWhenNodeCountExceeds4(t *testing.T) {
 
 	cluster = &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 5,
@@ -355,7 +355,7 @@ func TestNewESCRNoTolerations(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type:              "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{},
 			},
@@ -382,7 +382,7 @@ func TestNewESCRWithTolerations(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					Tolerations: expTolerations,
@@ -402,7 +402,7 @@ func TestNewESCRWithTolerations(t *testing.T) {
 func TestGenUUIDPreservedWhenNodeCountExceeds4(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 3,
@@ -416,7 +416,7 @@ func TestGenUUIDPreservedWhenNodeCountExceeds4(t *testing.T) {
 
 	cluster = &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 4,
@@ -439,7 +439,7 @@ func TestGenUUIDPreservedWhenNodeCountExceeds4(t *testing.T) {
 func TestGenUUIDPreservedWhenNodeCountChanges(t *testing.T) {
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 1,
@@ -453,7 +453,7 @@ func TestGenUUIDPreservedWhenNodeCountChanges(t *testing.T) {
 
 	cluster = &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			LogStore: logging.LogStoreSpec{
+			LogStore: &logging.LogStoreSpec{
 				Type: "elasticsearch",
 				ElasticsearchSpec: logging.ElasticsearchSpec{
 					NodeCount: 3,
